@@ -1,6 +1,7 @@
 package Mock::Basic::Schema;
 use utf8;
 use Teng::Schema::Declare;
+use DBI qw(:sql_types);
 
 table {
     name 'mock_basic';
@@ -32,5 +33,15 @@ table {
     /;
 };
 
+table {
+    name 'mock_basic_sql_types';
+    pk 'id';
+    columns(
+        {name => 'id'       , type => SQL_INTEGER},
+        {name => 'name'     , type => SQL_VARCHAR},
+        {name => 'delete_fg', type => SQL_BOOLEAN},
+    );
+};
+
 1;
 
