@@ -7,7 +7,7 @@ use Mock::Inflate::Name;
 table {
     name 'mock_inflate';
     pk qw/ id bar /;
-    columns qw/ id name foo bar /;
+    columns qw/ id name foo bar hash /;
     inflate 'name' => sub {
         my ($col_value) = @_;
         return Mock::Inflate::Name->new(name => $col_value);
@@ -32,6 +32,14 @@ table {
         my ($col_value) = @_;
         return ref $col_value ? $col_value->name : $col_value . '_deflate';
     };
+    inflate 'hash' => sub {
+        my ($col_value) = @_;
+        return { x => $col_value };
+    };
+    deflate 'hash' => sub {
+        my ($col_value) = @_;
+        return $col_value->{x};
+    };
 };
 
 1;
